
/**********************
***********************
Model comparisons
***********************
***********************/

/* 1. Compare a) all-times-before to the immediately-before model and b) all-times-before to the differential-sensitive-period model */

proc mixed data = alltimesbefore;
title "Compare the all-times-before, immediately-before, and the differential-sensitive-period models";
model outcome = 
			a1		/* indicator for age 1*/
			a2		/* indicator for age 2*/
			a3		/* indicator for age 3*/
			a4		/* indicator for age 4*/
		
			h21		/* indicator for age 2 x predictor from age 1*/
			h31		/* indicator for age 3 x predictor from age 1*/
			h32		/* indicator for age 3 x predictor from age 2*/
			h41		/* indicator for age 4 x predictor from age 1*/
			h42		/* indicator for age 4 x predictor from age 2*/
			h43		/* indicator for age 4 x predictor from age 3*/

			age			/* age at time outcome was measured */
			age*age		/* age squared at time outcome was measured */ 

			/ solution residual ddfm = kr2 noint CL;
random intercept age /type=un subject = pid;
contrast "all-times-before vs. immediately-before"
			h31		1,
			h41		1,			
			h42		1;
contrast "all-times-before vs. differential-sensitive-period"
			h32		1,
			h42		1,	
			h43		1;

run;


/* 2. Compare the differential-sensitive-period model and the stable-sensitive-period model. */

proc mixed data = AllTimesBefore;
title "compare the differential-sensitive-period model and stable-sensitive-period model";
model outcome = 
			a1		/* indicator for age 1*/
			a2		/* indicator for age 2*/
			a3		/* indicator for age 3*/
			a4		/* indicator for age 4*/

			h21		/* indicator for age 2 x predictor from age 1*/
			h31		/* indicator for age 3 x predictor from age 1*/
			h41		/* indicator for age 4 x predictor from age 1*/
			
			age
			age*age

			/ solution residual ddfm = kr2 noint CL;
random intercept age /type=un subject = pid;
contrast "equivalence of intercepts"
			a1		 1
			a2		-1,
			a1		 1
			a3		-1,
			a1		 1
			a4		-1;
contrast "equivalence of effortful control slopes"
			h21		1
			h31	   -1,
			h21		1
			h41	   -1;
contrast "equivalence of lines"
			a1		 1
			a2		-1,
			a1		 1
			a3		-1,
			a1		 1
			a4		-1,
			h21		1
			h31	   -1,
			h21		1
			h41	   -1;
run;


/**********************
***********************
Run final models
***********************
***********************/


/************************************************************************************************************
Run the all-times-before model using the dataset created for the all-times-before model "Alltimesbefore". 
*************************************************************************************************************/

proc mixed data = alltimesbefore;
title "run all-times-before model";
model outcome =
			a1		/* indicator for age 1*/
			a2		/* indicator for age 2*/
			a3		/* indicator for age 3*/
			a4		/* indicator for age 4*/
		
			h21		/* indicator for age 2 x predictor from age 1*/
			h31		/* indicator for age 3 x predictor from age 1*/
			h32		/* indicator for age 3 x predictor from age 2*/
			h41		/* indicator for age 4 x predictor from age 1*/
			h42		/* indicator for age 4 x predictor from age 2*/
			h43		/* indicator for age 4 x predictor from age 3*/

			/ solution residual ddfm = kr2 noint;
random intercept age /type=un subject = pid;
run;


/************************************************************************************************************
Run the immediately-before model using the dataset created for the all-times-before model "Alltimesbefore".
**************************************************************************************************************/

proc mixed data = AllTimesBefore;
title "immediately-before model with alltimesbefore dataset";
model outcome = 

			a1		/* indicator for age 1*/
			a2		/* indicator for age 2*/
			a3		/* indicator for age 3*/
			a4		/* indicator for age 4*/
		
			h21		/* indicator for age 2 x predictor from age 1*/
			h32		/* indicator for age 3 x predictor from age 2*/
			h43		/* indicator for age 4 x predictor from age 3*/

			
			/ solution residual ddfm = kr2 noint;
random intercept age /type=un subject = pid;
run;


/****************************************************************************************************************
Run the immediately-before model using the dataset created for the imeadiately-before model "Immediatelybefore".
*****************************************************************************************************************/

proc mixed data = ImmediatelyBefore;
title "immediately-before model with immediatelybefore dataset";
model outcome = 

			a1		/* indicator for age 1*/
			a2		/* indicator for age 2*/
			a3		/* indicator for age 3*/
			a4		/* indicator for age 4*/
		
			k21		/* indicator for age 2 x predictor from age 1*/
			k32		/* indicator for age 3 x predictor from age 2*/
			k43		/* indicator for age 4 x predictor from age 3*/

			
			/ solution residual ddfm = kr2 noint;
random intercept age /type=un subject = pid;
run;


/************************************************************************************************************************
Run the differential-sensitive-period model using the dataset created for the all-times-before model "Alltimesbefore".
*************************************************************************************************************************/

proc mixed data = AllTimesBefore;
title "differential-sensitive-period model";
model outcome = 
			a1		/* indicator for age 1*/
			a2		/* indicator for age 2*/
			a3		/* indicator for age 3*/
			a4		/* indicator for age 4*/

			h21		/* indicator for age 2 x predictor from age 1*/
			h31		/* indicator for age 3 x predictor from age 1*/
			h41		/* indicator for age 4 x predictor from age 1*/
			
			/ solution residual ddfm = kr2 noint CL;
random intercept age /type=un subject = pid;
run;


/********************************************************************************************************************************************
Run the differential-sensitive-period model using the dataset created for the differential-sensitive-period model "DifferentialSensitive".
*********************************************************************************************************************************************/

proc mixed data = DifferentialSensitive;
title "differential-sensitive-period model";
model outcome = 
			a1		/* indicator for age 1*/
			a2		/* indicator for age 2*/
			a3		/* indicator for age 3*/
			a4		/* indicator for age 4*/

			k21		/* indicator for age 2 x predictor from age 1*/
			k31		/* indicator for age 3 x predictor from age 1*/
			k41		/* indicator for age 4 x predictor from age 1*/

				
			/ solution residual ddfm = kr2 noint CL;
random intercept age /type=un subject = pid;
run;


/**************************************************************************************************************************
Run the stable-sensitive-period model using the dataset created for the all-times-before model "AllTimesBefore" 
***************************************************************************************************************************/

/* A single intercept must be added to this datatset. */
data AllTimesBefore;
set AllTimesBefore_2;
intercept = 1;
run;

proc mixed data = AllTimesBefore_2;
title "stable-sensitive-period model";
model outcome = 
			intercept		/* column of ones */
			i1				/* predictor from age 1*/
					
			/ solution residual ddfm = kr2 noint CL;
random intercept age /type=un subject = pid;
run;


/**************************************************************************************************************************
Run the stable-sensitive-period model using the dataset created for the stable-sensitive-period model "StableSensitive" 
***************************************************************************************************************************/


proc mixed data = StableSensitive;
title "stable-sensitive-period model";
model outcome = 
			intercept		/* column of ones */
			i1				/* predictor from age 1*/
					
			/ solution residual ddfm = kr2 noint CL;
random intercept age /type=un subject = pid;
run;


/**********************************************************
***********************************************************
Stable-sensitive-period model with moderator
***********************************************************
***********************************************************/

proc mixed data = StableSensitive;
title "stable-sensitive-period model";
model outcome = 
			intercept		/* column of ones */
			i1				/* predictor from age 1*/
			female			/* an indicator variable for female sex */
			il*female		/* two-way interaction between predictor from age 1 and indicator for female sex */
					
			/ solution residual ddfm = kr2 noint CL;
random intercept age /type=un subject = pid;
run;
